temporalsort

package module
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 27, 2021 License: MIT Imports: 2 Imported by: 0

README

TemporalSort

The sorting algorithm of the future. Runs in O(n) time (best, average, and worst case) using principles from physics and the linearity of time.

This module defines one function Sort([]int). It returns a sorted version of the list. Note that negative numbers are currently not supported.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Sort

func Sort(arr []int) []int

Sort takes in an `[]int`, and returns the sorted version of it using the TemporalSort algorithm.

Types

This section is empty.

Jump to